# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.4.0
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.

from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if getattr(globals().get("__spec__"), "parent", None) or __package__ or "." in __name__:
    from . import _pycec
else:
    import _pycec

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _pycec.delete_SwigPyIterator

    def value(self):
        return _pycec.SwigPyIterator_value(self)

    def incr(self, n=1):
        return _pycec.SwigPyIterator_incr(self, n)

    def decr(self, n=1):
        return _pycec.SwigPyIterator_decr(self, n)

    def distance(self, x):
        return _pycec.SwigPyIterator_distance(self, x)

    def equal(self, x):
        return _pycec.SwigPyIterator_equal(self, x)

    def copy(self):
        return _pycec.SwigPyIterator_copy(self)

    def next(self):
        return _pycec.SwigPyIterator_next(self)

    def __next__(self):
        return _pycec.SwigPyIterator___next__(self)

    def previous(self):
        return _pycec.SwigPyIterator_previous(self)

    def advance(self, n):
        return _pycec.SwigPyIterator_advance(self, n)

    def __eq__(self, x):
        return _pycec.SwigPyIterator___eq__(self, x)

    def __ne__(self, x):
        return _pycec.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n):
        return _pycec.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n):
        return _pycec.SwigPyIterator___isub__(self, n)

    def __add__(self, n):
        return _pycec.SwigPyIterator___add__(self, n)

    def __sub__(self, *args):
        return _pycec.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _pycec:
_pycec.SwigPyIterator_swigregister(SwigPyIterator)
class AdapterVector(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def iterator(self):
        return _pycec.AdapterVector_iterator(self)
    def __iter__(self):
        return self.iterator()

    def __nonzero__(self):
        return _pycec.AdapterVector___nonzero__(self)

    def __bool__(self):
        return _pycec.AdapterVector___bool__(self)

    def __len__(self):
        return _pycec.AdapterVector___len__(self)

    def __getslice__(self, i, j):
        return _pycec.AdapterVector___getslice__(self, i, j)

    def __setslice__(self, *args):
        return _pycec.AdapterVector___setslice__(self, *args)

    def __delslice__(self, i, j):
        return _pycec.AdapterVector___delslice__(self, i, j)

    def __delitem__(self, *args):
        return _pycec.AdapterVector___delitem__(self, *args)

    def __getitem__(self, *args):
        return _pycec.AdapterVector___getitem__(self, *args)

    def __setitem__(self, *args):
        return _pycec.AdapterVector___setitem__(self, *args)

    def pop(self):
        return _pycec.AdapterVector_pop(self)

    def append(self, x):
        return _pycec.AdapterVector_append(self, x)

    def empty(self):
        return _pycec.AdapterVector_empty(self)

    def size(self):
        return _pycec.AdapterVector_size(self)

    def swap(self, v):
        return _pycec.AdapterVector_swap(self, v)

    def begin(self):
        return _pycec.AdapterVector_begin(self)

    def end(self):
        return _pycec.AdapterVector_end(self)

    def rbegin(self):
        return _pycec.AdapterVector_rbegin(self)

    def rend(self):
        return _pycec.AdapterVector_rend(self)

    def clear(self):
        return _pycec.AdapterVector_clear(self)

    def get_allocator(self):
        return _pycec.AdapterVector_get_allocator(self)

    def pop_back(self):
        return _pycec.AdapterVector_pop_back(self)

    def erase(self, *args):
        return _pycec.AdapterVector_erase(self, *args)

    def __init__(self, *args):
        _pycec.AdapterVector_swiginit(self, _pycec.new_AdapterVector(*args))

    def push_back(self, x):
        return _pycec.AdapterVector_push_back(self, x)

    def front(self):
        return _pycec.AdapterVector_front(self)

    def back(self):
        return _pycec.AdapterVector_back(self)

    def assign(self, n, x):
        return _pycec.AdapterVector_assign(self, n, x)

    def resize(self, *args):
        return _pycec.AdapterVector_resize(self, *args)

    def insert(self, *args):
        return _pycec.AdapterVector_insert(self, *args)

    def reserve(self, n):
        return _pycec.AdapterVector_reserve(self, n)

    def capacity(self):
        return _pycec.AdapterVector_capacity(self)
    __swig_destroy__ = _pycec.delete_AdapterVector

# Register AdapterVector in _pycec:
_pycec.AdapterVector_swigregister(AdapterVector)
CEC_DEFAULT_PHYSICAL_ADDRESS = _pycec.CEC_DEFAULT_PHYSICAL_ADDRESS
CEC_DEFAULT_HDMI_PORT = _pycec.CEC_DEFAULT_HDMI_PORT
CEC_DEFAULT_BASE_DEVICE = _pycec.CEC_DEFAULT_BASE_DEVICE
CEC_BUTTON_TIMEOUT = _pycec.CEC_BUTTON_TIMEOUT
CEC_DOUBLE_TAP_TIMEOUT_MS = _pycec.CEC_DOUBLE_TAP_TIMEOUT_MS
CEC_POWER_STATE_REFRESH_TIME = _pycec.CEC_POWER_STATE_REFRESH_TIME
CEC_AUDIO_STATUS_REFRESH_TIME = _pycec.CEC_AUDIO_STATUS_REFRESH_TIME
CEC_FW_VERSION_UNKNOWN = _pycec.CEC_FW_VERSION_UNKNOWN
CEC_FW_BUILD_UNKNOWN = _pycec.CEC_FW_BUILD_UNKNOWN
CEC_CONNECT_TRIES = _pycec.CEC_CONNECT_TRIES
CEC_PHYSICAL_ADDRESS_TV = _pycec.CEC_PHYSICAL_ADDRESS_TV
CEC_MIN_PHYSICAL_ADDRESS = _pycec.CEC_MIN_PHYSICAL_ADDRESS
CEC_MAX_PHYSICAL_ADDRESS = _pycec.CEC_MAX_PHYSICAL_ADDRESS
CEC_INVALID_PHYSICAL_ADDRESS = _pycec.CEC_INVALID_PHYSICAL_ADDRESS
CEC_MIN_VENDORID = _pycec.CEC_MIN_VENDORID
CEC_MAX_VENDORID = _pycec.CEC_MAX_VENDORID
CEC_INVALID_VENDORID = _pycec.CEC_INVALID_VENDORID
CEC_MIN_HDMI_PORTNUMBER = _pycec.CEC_MIN_HDMI_PORTNUMBER
CEC_MAX_HDMI_PORTNUMBER = _pycec.CEC_MAX_HDMI_PORTNUMBER
CEC_HDMI_PORTNUMBER_NONE = _pycec.CEC_HDMI_PORTNUMBER_NONE
CEC_DEFAULT_SETTING_ACTIVATE_SOURCE = _pycec.CEC_DEFAULT_SETTING_ACTIVATE_SOURCE
CEC_DEFAULT_SETTING_POWER_OFF_SHUTDOWN = _pycec.CEC_DEFAULT_SETTING_POWER_OFF_SHUTDOWN
CEC_DEFAULT_SETTING_POWER_OFF_ON_STANDBY = _pycec.CEC_DEFAULT_SETTING_POWER_OFF_ON_STANDBY
CEC_DEFAULT_DEVICE_LANGUAGE = _pycec.CEC_DEFAULT_DEVICE_LANGUAGE
CEC_DEFAULT_SETTING_AUTODETECT_ADDRESS = _pycec.CEC_DEFAULT_SETTING_AUTODETECT_ADDRESS
CEC_DEFAULT_SETTING_GET_SETTINGS_FROM_ROM = _pycec.CEC_DEFAULT_SETTING_GET_SETTINGS_FROM_ROM
CEC_DEFAULT_SETTING_CEC_VERSION = _pycec.CEC_DEFAULT_SETTING_CEC_VERSION
CEC_DEFAULT_TRANSMIT_RETRY_WAIT = _pycec.CEC_DEFAULT_TRANSMIT_RETRY_WAIT
CEC_DEFAULT_TRANSMIT_TIMEOUT = _pycec.CEC_DEFAULT_TRANSMIT_TIMEOUT
CEC_DEFAULT_TRANSMIT_WAIT = _pycec.CEC_DEFAULT_TRANSMIT_WAIT
CEC_DEFAULT_TRANSMIT_RETRIES = _pycec.CEC_DEFAULT_TRANSMIT_RETRIES
CEC_DEFAULT_CONNECT_TIMEOUT = _pycec.CEC_DEFAULT_CONNECT_TIMEOUT
CEC_DEFAULT_CONNECT_RETRY_WAIT = _pycec.CEC_DEFAULT_CONNECT_RETRY_WAIT
CEC_SERIAL_DEFAULT_BAUDRATE = _pycec.CEC_SERIAL_DEFAULT_BAUDRATE
CEC_CLEAR_INPUT_DEFAULT_WAIT = _pycec.CEC_CLEAR_INPUT_DEFAULT_WAIT
CEC_ACTIVE_SOURCE_SWITCH_RETRY_TIME_MS = _pycec.CEC_ACTIVE_SOURCE_SWITCH_RETRY_TIME_MS
CEC_FORWARD_STANDBY_MIN_INTERVAL = _pycec.CEC_FORWARD_STANDBY_MIN_INTERVAL
CEC_DEFAULT_COMBO_TIMEOUT_MS = _pycec.CEC_DEFAULT_COMBO_TIMEOUT_MS
CEC_RPI_VIRTUAL_PATH = _pycec.CEC_RPI_VIRTUAL_PATH
CEC_RPI_VIRTUAL_COM = _pycec.CEC_RPI_VIRTUAL_COM
CEC_TDA995x_PATH = _pycec.CEC_TDA995x_PATH
CEC_TDA995x_VIRTUAL_COM = _pycec.CEC_TDA995x_VIRTUAL_COM
CEC_EXYNOS_PATH = _pycec.CEC_EXYNOS_PATH
CEC_EXYNOS_VIRTUAL_COM = _pycec.CEC_EXYNOS_VIRTUAL_COM
CEC_MAX_DATA_PACKET_SIZE = _pycec.CEC_MAX_DATA_PACKET_SIZE
CEC_LINUX_PATH = _pycec.CEC_LINUX_PATH
CEC_LINUX_VIRTUAL_COM = _pycec.CEC_LINUX_VIRTUAL_COM
CEC_AOCEC_PATH = _pycec.CEC_AOCEC_PATH
CEC_AOCEC_VIRTUAL_COM = _pycec.CEC_AOCEC_VIRTUAL_COM
CEC_IMX_PATH = _pycec.CEC_IMX_PATH
CEC_IMX_VIRTUAL_COM = _pycec.CEC_IMX_VIRTUAL_COM
CEC_MIN_LIB_VERSION = _pycec.CEC_MIN_LIB_VERSION
MSGSTART = _pycec.MSGSTART
MSGEND = _pycec.MSGEND
MSGESC = _pycec.MSGESC
ESCOFFSET = _pycec.ESCOFFSET
DOUBLE_TAP_TIMEOUT_UNIT_SIZE = _pycec.DOUBLE_TAP_TIMEOUT_UNIT_SIZE
CEC_FEATURE_CONFIGURABLE_COMBO_KEY = _pycec.CEC_FEATURE_CONFIGURABLE_COMBO_KEY
CEC_ABORT_REASON_UNRECOGNIZED_OPCODE = _pycec.CEC_ABORT_REASON_UNRECOGNIZED_OPCODE
CEC_ABORT_REASON_NOT_IN_CORRECT_MODE_TO_RESPOND = _pycec.CEC_ABORT_REASON_NOT_IN_CORRECT_MODE_TO_RESPOND
CEC_ABORT_REASON_CANNOT_PROVIDE_SOURCE = _pycec.CEC_ABORT_REASON_CANNOT_PROVIDE_SOURCE
CEC_ABORT_REASON_INVALID_OPERAND = _pycec.CEC_ABORT_REASON_INVALID_OPERAND
CEC_ABORT_REASON_REFUSED = _pycec.CEC_ABORT_REASON_REFUSED
CEC_ANALOGUE_BROADCAST_TYPE_CABLE = _pycec.CEC_ANALOGUE_BROADCAST_TYPE_CABLE
CEC_ANALOGUE_BROADCAST_TYPE_SATELLITE = _pycec.CEC_ANALOGUE_BROADCAST_TYPE_SATELLITE
CEC_ANALOGUE_BROADCAST_TYPE_TERRESTIAL = _pycec.CEC_ANALOGUE_BROADCAST_TYPE_TERRESTIAL
CEC_AUDIO_RATE_RATE_CONTROL_OFF = _pycec.CEC_AUDIO_RATE_RATE_CONTROL_OFF
CEC_AUDIO_RATE_STANDARD_RATE_100 = _pycec.CEC_AUDIO_RATE_STANDARD_RATE_100
CEC_AUDIO_RATE_FAST_RATE_MAX_101 = _pycec.CEC_AUDIO_RATE_FAST_RATE_MAX_101
CEC_AUDIO_RATE_SLOW_RATE_MIN_99 = _pycec.CEC_AUDIO_RATE_SLOW_RATE_MIN_99
CEC_AUDIO_RATE_STANDARD_RATE_100_0 = _pycec.CEC_AUDIO_RATE_STANDARD_RATE_100_0
CEC_AUDIO_RATE_FAST_RATE_MAX_100_1 = _pycec.CEC_AUDIO_RATE_FAST_RATE_MAX_100_1
CEC_AUDIO_RATE_SLOW_RATE_MIN_99_9 = _pycec.CEC_AUDIO_RATE_SLOW_RATE_MIN_99_9
CEC_AUDIO_MUTE_STATUS_MASK = _pycec.CEC_AUDIO_MUTE_STATUS_MASK
CEC_AUDIO_VOLUME_STATUS_MASK = _pycec.CEC_AUDIO_VOLUME_STATUS_MASK
CEC_AUDIO_VOLUME_MIN = _pycec.CEC_AUDIO_VOLUME_MIN
CEC_AUDIO_VOLUME_MAX = _pycec.CEC_AUDIO_VOLUME_MAX
CEC_AUDIO_VOLUME_STATUS_UNKNOWN = _pycec.CEC_AUDIO_VOLUME_STATUS_UNKNOWN
CEC_FALSE = _pycec.CEC_FALSE
CEC_TRUE = _pycec.CEC_TRUE
CEC_VERSION_UNKNOWN = _pycec.CEC_VERSION_UNKNOWN
CEC_VERSION_1_2 = _pycec.CEC_VERSION_1_2
CEC_VERSION_1_2A = _pycec.CEC_VERSION_1_2A
CEC_VERSION_1_3 = _pycec.CEC_VERSION_1_3
CEC_VERSION_1_3A = _pycec.CEC_VERSION_1_3A
CEC_VERSION_1_4 = _pycec.CEC_VERSION_1_4
CEC_VERSION_2_0 = _pycec.CEC_VERSION_2_0
CEC_CHANNEL_NUMBER_FORMAT_MASK = _pycec.CEC_CHANNEL_NUMBER_FORMAT_MASK
CEC_1_PART_CHANNEL_NUMBER = _pycec.CEC_1_PART_CHANNEL_NUMBER
CEC_2_PART_CHANNEL_NUMBER = _pycec.CEC_2_PART_CHANNEL_NUMBER
CEC_MAJOR_CHANNEL_NUMBER_MASK = _pycec.CEC_MAJOR_CHANNEL_NUMBER_MASK
CEC_MINOR_CHANNEL_NUMBER_MASK = _pycec.CEC_MINOR_CHANNEL_NUMBER_MASK
CEC_DECK_CONTROL_MODE_SKIP_FORWARD_WIND = _pycec.CEC_DECK_CONTROL_MODE_SKIP_FORWARD_WIND
CEC_DECK_CONTROL_MODE_SKIP_REVERSE_REWIND = _pycec.CEC_DECK_CONTROL_MODE_SKIP_REVERSE_REWIND
CEC_DECK_CONTROL_MODE_STOP = _pycec.CEC_DECK_CONTROL_MODE_STOP
CEC_DECK_CONTROL_MODE_EJECT = _pycec.CEC_DECK_CONTROL_MODE_EJECT
CEC_DECK_INFO_PLAY = _pycec.CEC_DECK_INFO_PLAY
CEC_DECK_INFO_RECORD = _pycec.CEC_DECK_INFO_RECORD
CEC_DECK_INFO_PLAY_REVERSE = _pycec.CEC_DECK_INFO_PLAY_REVERSE
CEC_DECK_INFO_STILL = _pycec.CEC_DECK_INFO_STILL
CEC_DECK_INFO_SLOW = _pycec.CEC_DECK_INFO_SLOW
CEC_DECK_INFO_SLOW_REVERSE = _pycec.CEC_DECK_INFO_SLOW_REVERSE
CEC_DECK_INFO_FAST_FORWARD = _pycec.CEC_DECK_INFO_FAST_FORWARD
CEC_DECK_INFO_FAST_REVERSE = _pycec.CEC_DECK_INFO_FAST_REVERSE
CEC_DECK_INFO_NO_MEDIA = _pycec.CEC_DECK_INFO_NO_MEDIA
CEC_DECK_INFO_STOP = _pycec.CEC_DECK_INFO_STOP
CEC_DECK_INFO_SKIP_FORWARD_WIND = _pycec.CEC_DECK_INFO_SKIP_FORWARD_WIND
CEC_DECK_INFO_SKIP_REVERSE_REWIND = _pycec.CEC_DECK_INFO_SKIP_REVERSE_REWIND
CEC_DECK_INFO_INDEX_SEARCH_FORWARD = _pycec.CEC_DECK_INFO_INDEX_SEARCH_FORWARD
CEC_DECK_INFO_INDEX_SEARCH_REVERSE = _pycec.CEC_DECK_INFO_INDEX_SEARCH_REVERSE
CEC_DECK_INFO_OTHER_STATUS = _pycec.CEC_DECK_INFO_OTHER_STATUS
CEC_DECK_INFO_OTHER_STATUS_LG = _pycec.CEC_DECK_INFO_OTHER_STATUS_LG
CEC_DEVICE_TYPE_TV = _pycec.CEC_DEVICE_TYPE_TV
CEC_DEVICE_TYPE_RECORDING_DEVICE = _pycec.CEC_DEVICE_TYPE_RECORDING_DEVICE
CEC_DEVICE_TYPE_RESERVED = _pycec.CEC_DEVICE_TYPE_RESERVED
CEC_DEVICE_TYPE_TUNER = _pycec.CEC_DEVICE_TYPE_TUNER
CEC_DEVICE_TYPE_PLAYBACK_DEVICE = _pycec.CEC_DEVICE_TYPE_PLAYBACK_DEVICE
CEC_DEVICE_TYPE_AUDIO_SYSTEM = _pycec.CEC_DEVICE_TYPE_AUDIO_SYSTEM
CEC_DISPLAY_CONTROL_DISPLAY_FOR_DEFAULT_TIME = _pycec.CEC_DISPLAY_CONTROL_DISPLAY_FOR_DEFAULT_TIME
CEC_DISPLAY_CONTROL_DISPLAY_UNTIL_CLEARED = _pycec.CEC_DISPLAY_CONTROL_DISPLAY_UNTIL_CLEARED
CEC_DISPLAY_CONTROL_CLEAR_PREVIOUS_MESSAGE = _pycec.CEC_DISPLAY_CONTROL_CLEAR_PREVIOUS_MESSAGE
CEC_DISPLAY_CONTROL_RESERVED_FOR_FUTURE_USE = _pycec.CEC_DISPLAY_CONTROL_RESERVED_FOR_FUTURE_USE
CEC_EXTERNAL_SOURCE_SPECIFIER_EXTERNAL_PLUG = _pycec.CEC_EXTERNAL_SOURCE_SPECIFIER_EXTERNAL_PLUG
CEC_EXTERNAL_SOURCE_SPECIFIER_EXTERNAL_PHYSICAL_ADDRESS = _pycec.CEC_EXTERNAL_SOURCE_SPECIFIER_EXTERNAL_PHYSICAL_ADDRESS
CEC_MENU_REQUEST_TYPE_ACTIVATE = _pycec.CEC_MENU_REQUEST_TYPE_ACTIVATE
CEC_MENU_REQUEST_TYPE_DEACTIVATE = _pycec.CEC_MENU_REQUEST_TYPE_DEACTIVATE
CEC_MENU_REQUEST_TYPE_QUERY = _pycec.CEC_MENU_REQUEST_TYPE_QUERY
CEC_MENU_STATE_ACTIVATED = _pycec.CEC_MENU_STATE_ACTIVATED
CEC_MENU_STATE_DEACTIVATED = _pycec.CEC_MENU_STATE_DEACTIVATED
CEC_PLAY_MODE_PLAY_FORWARD = _pycec.CEC_PLAY_MODE_PLAY_FORWARD
CEC_PLAY_MODE_PLAY_REVERSE = _pycec.CEC_PLAY_MODE_PLAY_REVERSE
CEC_PLAY_MODE_PLAY_STILL = _pycec.CEC_PLAY_MODE_PLAY_STILL
CEC_PLAY_MODE_FAST_FORWARD_MIN_SPEED = _pycec.CEC_PLAY_MODE_FAST_FORWARD_MIN_SPEED
CEC_PLAY_MODE_FAST_FORWARD_MEDIUM_SPEED = _pycec.CEC_PLAY_MODE_FAST_FORWARD_MEDIUM_SPEED
CEC_PLAY_MODE_FAST_FORWARD_MAX_SPEED = _pycec.CEC_PLAY_MODE_FAST_FORWARD_MAX_SPEED
CEC_PLAY_MODE_FAST_REVERSE_MIN_SPEED = _pycec.CEC_PLAY_MODE_FAST_REVERSE_MIN_SPEED
CEC_PLAY_MODE_FAST_REVERSE_MEDIUM_SPEED = _pycec.CEC_PLAY_MODE_FAST_REVERSE_MEDIUM_SPEED
CEC_PLAY_MODE_FAST_REVERSE_MAX_SPEED = _pycec.CEC_PLAY_MODE_FAST_REVERSE_MAX_SPEED
CEC_PLAY_MODE_SLOW_FORWARD_MIN_SPEED = _pycec.CEC_PLAY_MODE_SLOW_FORWARD_MIN_SPEED
CEC_PLAY_MODE_SLOW_FORWARD_MEDIUM_SPEED = _pycec.CEC_PLAY_MODE_SLOW_FORWARD_MEDIUM_SPEED
CEC_PLAY_MODE_SLOW_FORWARD_MAX_SPEED = _pycec.CEC_PLAY_MODE_SLOW_FORWARD_MAX_SPEED
CEC_PLAY_MODE_SLOW_REVERSE_MIN_SPEED = _pycec.CEC_PLAY_MODE_SLOW_REVERSE_MIN_SPEED
CEC_PLAY_MODE_SLOW_REVERSE_MEDIUM_SPEED = _pycec.CEC_PLAY_MODE_SLOW_REVERSE_MEDIUM_SPEED
CEC_PLAY_MODE_SLOW_REVERSE_MAX_SPEED = _pycec.CEC_PLAY_MODE_SLOW_REVERSE_MAX_SPEED
CEC_POWER_STATUS_ON = _pycec.CEC_POWER_STATUS_ON
CEC_POWER_STATUS_STANDBY = _pycec.CEC_POWER_STATUS_STANDBY
CEC_POWER_STATUS_IN_TRANSITION_STANDBY_TO_ON = _pycec.CEC_POWER_STATUS_IN_TRANSITION_STANDBY_TO_ON
CEC_POWER_STATUS_IN_TRANSITION_ON_TO_STANDBY = _pycec.CEC_POWER_STATUS_IN_TRANSITION_ON_TO_STANDBY
CEC_POWER_STATUS_UNKNOWN = _pycec.CEC_POWER_STATUS_UNKNOWN
CEC_RECORD_SOURCE_TYPE_OWN_SOURCE = _pycec.CEC_RECORD_SOURCE_TYPE_OWN_SOURCE
CEC_RECORD_SOURCE_TYPE_DIGITAL_SERVICE = _pycec.CEC_RECORD_SOURCE_TYPE_DIGITAL_SERVICE
CEC_RECORD_SOURCE_TYPE_ANALOGUE_SERVICE = _pycec.CEC_RECORD_SOURCE_TYPE_ANALOGUE_SERVICE
CEC_RECORD_SOURCE_TYPE_EXTERNAL_PLUS = _pycec.CEC_RECORD_SOURCE_TYPE_EXTERNAL_PLUS
CEC_RECORD_SOURCE_TYPE_EXTERNAL_PHYSICAL_ADDRESS = _pycec.CEC_RECORD_SOURCE_TYPE_EXTERNAL_PHYSICAL_ADDRESS
CEC_RECORD_STATUS_INFO_RECORDING_CURRENTLY_SELECTED_SOURCE = _pycec.CEC_RECORD_STATUS_INFO_RECORDING_CURRENTLY_SELECTED_SOURCE
CEC_RECORD_STATUS_INFO_RECORDING_DIGITAL_SERVICE = _pycec.CEC_RECORD_STATUS_INFO_RECORDING_DIGITAL_SERVICE
CEC_RECORD_STATUS_INFO_RECORDING_ANALOGUE_SERVICE = _pycec.CEC_RECORD_STATUS_INFO_RECORDING_ANALOGUE_SERVICE
CEC_RECORD_STATUS_INFO_RECORDING_EXTERNAL_INPUT = _pycec.CEC_RECORD_STATUS_INFO_RECORDING_EXTERNAL_INPUT
CEC_RECORD_STATUS_INFO_NO_RECORDING_UNABLE_TO_RECORD_DIGITAL_SERVICE = _pycec.CEC_RECORD_STATUS_INFO_NO_RECORDING_UNABLE_TO_RECORD_DIGITAL_SERVICE
CEC_RECORD_STATUS_INFO_NO_RECORDING_UNABLE_TO_RECORD_ANALOGUE_SERVICE = _pycec.CEC_RECORD_STATUS_INFO_NO_RECORDING_UNABLE_TO_RECORD_ANALOGUE_SERVICE
CEC_RECORD_STATUS_INFO_NO_RECORDING_UNABLE_TO_SELECT_REQUIRED_SERVICE = _pycec.CEC_RECORD_STATUS_INFO_NO_RECORDING_UNABLE_TO_SELECT_REQUIRED_SERVICE
CEC_RECORD_STATUS_INFO_NO_RECORDING_INVALID_EXTERNAL_PLUG_NUMBER = _pycec.CEC_RECORD_STATUS_INFO_NO_RECORDING_INVALID_EXTERNAL_PLUG_NUMBER
CEC_RECORD_STATUS_INFO_NO_RECORDING_INVALID_EXTERNAL_ADDRESS = _pycec.CEC_RECORD_STATUS_INFO_NO_RECORDING_INVALID_EXTERNAL_ADDRESS
CEC_RECORD_STATUS_INFO_NO_RECORDING_CA_SYSTEM_NOT_SUPPORTED = _pycec.CEC_RECORD_STATUS_INFO_NO_RECORDING_CA_SYSTEM_NOT_SUPPORTED
CEC_RECORD_STATUS_INFO_NO_RECORDING_NO_OR_INSUFFICIENT_ENTITLEMENTS = _pycec.CEC_RECORD_STATUS_INFO_NO_RECORDING_NO_OR_INSUFFICIENT_ENTITLEMENTS
CEC_RECORD_STATUS_INFO_NO_RECORDING_NOT_ALLOWED_TO_COPY_SOURCE = _pycec.CEC_RECORD_STATUS_INFO_NO_RECORDING_NOT_ALLOWED_TO_COPY_SOURCE
CEC_RECORD_STATUS_INFO_NO_RECORDING_NO_FURTHER_COPIES_ALLOWED = _pycec.CEC_RECORD_STATUS_INFO_NO_RECORDING_NO_FURTHER_COPIES_ALLOWED
CEC_RECORD_STATUS_INFO_NO_RECORDING_NO_MEDIA = _pycec.CEC_RECORD_STATUS_INFO_NO_RECORDING_NO_MEDIA
CEC_RECORD_STATUS_INFO_NO_RECORDING_PLAYING = _pycec.CEC_RECORD_STATUS_INFO_NO_RECORDING_PLAYING
CEC_RECORD_STATUS_INFO_NO_RECORDING_ALREADY_RECORDING = _pycec.CEC_RECORD_STATUS_INFO_NO_RECORDING_ALREADY_RECORDING
CEC_RECORD_STATUS_INFO_NO_RECORDING_MEDIA_PROTECTED = _pycec.CEC_RECORD_STATUS_INFO_NO_RECORDING_MEDIA_PROTECTED
CEC_RECORD_STATUS_INFO_NO_RECORDING_NO_SOURCE_SIGNAL = _pycec.CEC_RECORD_STATUS_INFO_NO_RECORDING_NO_SOURCE_SIGNAL
CEC_RECORD_STATUS_INFO_NO_RECORDING_MEDIA_PROBLEM = _pycec.CEC_RECORD_STATUS_INFO_NO_RECORDING_MEDIA_PROBLEM
CEC_RECORD_STATUS_INFO_NO_RECORDING_NOT_ENOUGH_SPACE_AVAILABLE = _pycec.CEC_RECORD_STATUS_INFO_NO_RECORDING_NOT_ENOUGH_SPACE_AVAILABLE
CEC_RECORD_STATUS_INFO_NO_RECORDING_PARENTAL_LOCK_ON = _pycec.CEC_RECORD_STATUS_INFO_NO_RECORDING_PARENTAL_LOCK_ON
CEC_RECORD_STATUS_INFO_RECORDING_TERMINATED_NORMALLY = _pycec.CEC_RECORD_STATUS_INFO_RECORDING_TERMINATED_NORMALLY
CEC_RECORD_STATUS_INFO_RECORDING_HAS_ALREADY_TERMINATED = _pycec.CEC_RECORD_STATUS_INFO_RECORDING_HAS_ALREADY_TERMINATED
CEC_RECORD_STATUS_INFO_NO_RECORDING_OTHER_REASON = _pycec.CEC_RECORD_STATUS_INFO_NO_RECORDING_OTHER_REASON
CEC_RECORDING_SEQUENCE_SUNDAY = _pycec.CEC_RECORDING_SEQUENCE_SUNDAY
CEC_RECORDING_SEQUENCE_MONDAY = _pycec.CEC_RECORDING_SEQUENCE_MONDAY
CEC_RECORDING_SEQUENCE_TUESDAY = _pycec.CEC_RECORDING_SEQUENCE_TUESDAY
CEC_RECORDING_SEQUENCE_WEDNESDAY = _pycec.CEC_RECORDING_SEQUENCE_WEDNESDAY
CEC_RECORDING_SEQUENCE_THURSDAY = _pycec.CEC_RECORDING_SEQUENCE_THURSDAY
CEC_RECORDING_SEQUENCE_FRIDAY = _pycec.CEC_RECORDING_SEQUENCE_FRIDAY
CEC_RECORDING_SEQUENCE_SATURDAY = _pycec.CEC_RECORDING_SEQUENCE_SATURDAY
CEC_RECORDING_SEQUENCE_ONCE_ONLY = _pycec.CEC_RECORDING_SEQUENCE_ONCE_ONLY
CEC_STATUS_REQUEST_ON = _pycec.CEC_STATUS_REQUEST_ON
CEC_STATUS_REQUEST_OFF = _pycec.CEC_STATUS_REQUEST_OFF
CEC_STATUS_REQUEST_ONCE = _pycec.CEC_STATUS_REQUEST_ONCE
CEC_SYSTEM_AUDIO_STATUS_OFF = _pycec.CEC_SYSTEM_AUDIO_STATUS_OFF
CEC_SYSTEM_AUDIO_STATUS_ON = _pycec.CEC_SYSTEM_AUDIO_STATUS_ON
CEC_SYSTEM_AUDIO_STATUS_UNKNOWN = _pycec.CEC_SYSTEM_AUDIO_STATUS_UNKNOWN
CEC_TIMER_CLEARED_STATUS_DATA_TIMER_NOT_CLEARED_RECORDING = _pycec.CEC_TIMER_CLEARED_STATUS_DATA_TIMER_NOT_CLEARED_RECORDING
CEC_TIMER_CLEARED_STATUS_DATA_TIMER_NOT_CLEARED_NO_MATCHING = _pycec.CEC_TIMER_CLEARED_STATUS_DATA_TIMER_NOT_CLEARED_NO_MATCHING
CEC_TIMER_CLEARED_STATUS_DATA_TIMER_NOT_CLEARED_NO_INF0_AVAILABLE = _pycec.CEC_TIMER_CLEARED_STATUS_DATA_TIMER_NOT_CLEARED_NO_INF0_AVAILABLE
CEC_TIMER_CLEARED_STATUS_DATA_TIMER_CLEARED = _pycec.CEC_TIMER_CLEARED_STATUS_DATA_TIMER_CLEARED
CEC_TIMER_OVERLAP_WARNING_NO_OVERLAP = _pycec.CEC_TIMER_OVERLAP_WARNING_NO_OVERLAP
CEC_TIMER_OVERLAP_WARNING_TIMER_BLOCKS_OVERLAP = _pycec.CEC_TIMER_OVERLAP_WARNING_TIMER_BLOCKS_OVERLAP
CEC_MEDIA_INFO_MEDIA_PRESENT_AND_NOT_PROTECTED = _pycec.CEC_MEDIA_INFO_MEDIA_PRESENT_AND_NOT_PROTECTED
CEC_MEDIA_INFO_MEDIA_PRESENT_BUT_PROTECTED = _pycec.CEC_MEDIA_INFO_MEDIA_PRESENT_BUT_PROTECTED
CEC_MEDIA_INFO_MEDIA_NOT_PRESENT = _pycec.CEC_MEDIA_INFO_MEDIA_NOT_PRESENT
CEC_MEDIA_INFO_FUTURE_USE = _pycec.CEC_MEDIA_INFO_FUTURE_USE
CEC_PROGRAMMED_INDICATOR_NOT_PROGRAMMED = _pycec.CEC_PROGRAMMED_INDICATOR_NOT_PROGRAMMED
CEC_PROGRAMMED_INDICATOR_PROGRAMMED = _pycec.CEC_PROGRAMMED_INDICATOR_PROGRAMMED
CEC_PROGRAMMED_INFO_FUTURE_USE = _pycec.CEC_PROGRAMMED_INFO_FUTURE_USE
CEC_PROGRAMMED_INFO_ENOUGH_SPACE_AVAILABLE_FOR_RECORDING = _pycec.CEC_PROGRAMMED_INFO_ENOUGH_SPACE_AVAILABLE_FOR_RECORDING
CEC_PROGRAMMED_INFO_NOT_ENOUGH_SPACE_AVAILABLE_FOR_RECORDING = _pycec.CEC_PROGRAMMED_INFO_NOT_ENOUGH_SPACE_AVAILABLE_FOR_RECORDING
CEC_PROGRAMMED_INFO_MAY_NOT_BE_ENOUGH_SPACE_AVAILABLE = _pycec.CEC_PROGRAMMED_INFO_MAY_NOT_BE_ENOUGH_SPACE_AVAILABLE
CEC_PROGRAMMED_INFO_NO_MEDIA_INFO_AVAILABLE = _pycec.CEC_PROGRAMMED_INFO_NO_MEDIA_INFO_AVAILABLE
CEC_NOT_PROGRAMMED_ERROR_INFO_FUTURE_USE = _pycec.CEC_NOT_PROGRAMMED_ERROR_INFO_FUTURE_USE
CEC_NOT_PROGRAMMED_ERROR_INFO_NO_FREE_TIMER_AVAILABLE = _pycec.CEC_NOT_PROGRAMMED_ERROR_INFO_NO_FREE_TIMER_AVAILABLE
CEC_NOT_PROGRAMMED_ERROR_INFO_DATE_OUT_OF_RANGE = _pycec.CEC_NOT_PROGRAMMED_ERROR_INFO_DATE_OUT_OF_RANGE
CEC_NOT_PROGRAMMED_ERROR_INFO_RECORDING_SEQUENCE_ERROR = _pycec.CEC_NOT_PROGRAMMED_ERROR_INFO_RECORDING_SEQUENCE_ERROR
CEC_NOT_PROGRAMMED_ERROR_INFO_INVALID_EXTERNAL_PLUG_NUMBER = _pycec.CEC_NOT_PROGRAMMED_ERROR_INFO_INVALID_EXTERNAL_PLUG_NUMBER
CEC_NOT_PROGRAMMED_ERROR_INFO_INVALID_EXTERNAL_PHYSICAL_ADDRESS = _pycec.CEC_NOT_PROGRAMMED_ERROR_INFO_INVALID_EXTERNAL_PHYSICAL_ADDRESS
CEC_NOT_PROGRAMMED_ERROR_INFO_CA_SYSTEM_NOT_SUPPORTED = _pycec.CEC_NOT_PROGRAMMED_ERROR_INFO_CA_SYSTEM_NOT_SUPPORTED
CEC_NOT_PROGRAMMED_ERROR_INFO_NO_OR_INSUFFICIENT_CA_ENTITLEMENTS = _pycec.CEC_NOT_PROGRAMMED_ERROR_INFO_NO_OR_INSUFFICIENT_CA_ENTITLEMENTS
CEC_NOT_PROGRAMMED_ERROR_INFO_DOES_NOT_SUPPORT_RESOLUTION = _pycec.CEC_NOT_PROGRAMMED_ERROR_INFO_DOES_NOT_SUPPORT_RESOLUTION
CEC_NOT_PROGRAMMED_ERROR_INFO_PARENTAL_LOCK_ON = _pycec.CEC_NOT_PROGRAMMED_ERROR_INFO_PARENTAL_LOCK_ON
CEC_NOT_PROGRAMMED_ERROR_INFO_CLOCK_FAILURE = _pycec.CEC_NOT_PROGRAMMED_ERROR_INFO_CLOCK_FAILURE
CEC_NOT_PROGRAMMED_ERROR_INFO_RESERVED_FOR_FUTURE_USE_START = _pycec.CEC_NOT_PROGRAMMED_ERROR_INFO_RESERVED_FOR_FUTURE_USE_START
CEC_NOT_PROGRAMMED_ERROR_INFO_RESERVED_FOR_FUTURE_USE_END = _pycec.CEC_NOT_PROGRAMMED_ERROR_INFO_RESERVED_FOR_FUTURE_USE_END
CEC_NOT_PROGRAMMED_ERROR_INFO_DUPLICATE_ALREADY_PROGRAMMED = _pycec.CEC_NOT_PROGRAMMED_ERROR_INFO_DUPLICATE_ALREADY_PROGRAMMED
CEC_RECORDING_FLAG_NOT_BEING_USED_FOR_RECORDING = _pycec.CEC_RECORDING_FLAG_NOT_BEING_USED_FOR_RECORDING
CEC_RECORDING_FLAG_BEING_USED_FOR_RECORDING = _pycec.CEC_RECORDING_FLAG_BEING_USED_FOR_RECORDING
CEC_TUNER_DISPLAY_INFO_DISPLAYING_DIGITAL_TUNER = _pycec.CEC_TUNER_DISPLAY_INFO_DISPLAYING_DIGITAL_TUNER
CEC_TUNER_DISPLAY_INFO_NOT_DISPLAYING_TUNER = _pycec.CEC_TUNER_DISPLAY_INFO_NOT_DISPLAYING_TUNER
CEC_TUNER_DISPLAY_INFO_DISPLAYING_ANALOGUE_TUNER = _pycec.CEC_TUNER_DISPLAY_INFO_DISPLAYING_ANALOGUE_TUNER
CEC_BROADCAST_SYSTEM_PAL_B_G = _pycec.CEC_BROADCAST_SYSTEM_PAL_B_G
CEC_BROADCAST_SYSTEM_SECAM_L1 = _pycec.CEC_BROADCAST_SYSTEM_SECAM_L1
CEC_BROADCAST_SYSTEM_PAL_M = _pycec.CEC_BROADCAST_SYSTEM_PAL_M
CEC_BROADCAST_SYSTEM_NTSC_M = _pycec.CEC_BROADCAST_SYSTEM_NTSC_M
CEC_BROADCAST_SYSTEM_PAL_I = _pycec.CEC_BROADCAST_SYSTEM_PAL_I
CEC_BROADCAST_SYSTEM_SECAM_DK = _pycec.CEC_BROADCAST_SYSTEM_SECAM_DK
CEC_BROADCAST_SYSTEM_SECAM_B_G = _pycec.CEC_BROADCAST_SYSTEM_SECAM_B_G
CEC_BROADCAST_SYSTEM_SECAM_L2 = _pycec.CEC_BROADCAST_SYSTEM_SECAM_L2
CEC_BROADCAST_SYSTEM_PAL_DK = _pycec.CEC_BROADCAST_SYSTEM_PAL_DK
CEC_BROADCAST_SYSTEM_OTHER_SYSTEM = _pycec.CEC_BROADCAST_SYSTEM_OTHER_SYSTEM
CEC_USER_CONTROL_CODE_SELECT = _pycec.CEC_USER_CONTROL_CODE_SELECT
CEC_USER_CONTROL_CODE_UP = _pycec.CEC_USER_CONTROL_CODE_UP
CEC_USER_CONTROL_CODE_DOWN = _pycec.CEC_USER_CONTROL_CODE_DOWN
CEC_USER_CONTROL_CODE_LEFT = _pycec.CEC_USER_CONTROL_CODE_LEFT
CEC_USER_CONTROL_CODE_RIGHT = _pycec.CEC_USER_CONTROL_CODE_RIGHT
CEC_USER_CONTROL_CODE_RIGHT_UP = _pycec.CEC_USER_CONTROL_CODE_RIGHT_UP
CEC_USER_CONTROL_CODE_RIGHT_DOWN = _pycec.CEC_USER_CONTROL_CODE_RIGHT_DOWN
CEC_USER_CONTROL_CODE_LEFT_UP = _pycec.CEC_USER_CONTROL_CODE_LEFT_UP
CEC_USER_CONTROL_CODE_LEFT_DOWN = _pycec.CEC_USER_CONTROL_CODE_LEFT_DOWN
CEC_USER_CONTROL_CODE_ROOT_MENU = _pycec.CEC_USER_CONTROL_CODE_ROOT_MENU
CEC_USER_CONTROL_CODE_SETUP_MENU = _pycec.CEC_USER_CONTROL_CODE_SETUP_MENU
CEC_USER_CONTROL_CODE_CONTENTS_MENU = _pycec.CEC_USER_CONTROL_CODE_CONTENTS_MENU
CEC_USER_CONTROL_CODE_FAVORITE_MENU = _pycec.CEC_USER_CONTROL_CODE_FAVORITE_MENU
CEC_USER_CONTROL_CODE_EXIT = _pycec.CEC_USER_CONTROL_CODE_EXIT
CEC_USER_CONTROL_CODE_TOP_MENU = _pycec.CEC_USER_CONTROL_CODE_TOP_MENU
CEC_USER_CONTROL_CODE_DVD_MENU = _pycec.CEC_USER_CONTROL_CODE_DVD_MENU
CEC_USER_CONTROL_CODE_NUMBER_ENTRY_MODE = _pycec.CEC_USER_CONTROL_CODE_NUMBER_ENTRY_MODE
CEC_USER_CONTROL_CODE_NUMBER11 = _pycec.CEC_USER_CONTROL_CODE_NUMBER11
CEC_USER_CONTROL_CODE_NUMBER12 = _pycec.CEC_USER_CONTROL_CODE_NUMBER12
CEC_USER_CONTROL_CODE_NUMBER0 = _pycec.CEC_USER_CONTROL_CODE_NUMBER0
CEC_USER_CONTROL_CODE_NUMBER1 = _pycec.CEC_USER_CONTROL_CODE_NUMBER1
CEC_USER_CONTROL_CODE_NUMBER2 = _pycec.CEC_USER_CONTROL_CODE_NUMBER2
CEC_USER_CONTROL_CODE_NUMBER3 = _pycec.CEC_USER_CONTROL_CODE_NUMBER3
CEC_USER_CONTROL_CODE_NUMBER4 = _pycec.CEC_USER_CONTROL_CODE_NUMBER4
CEC_USER_CONTROL_CODE_NUMBER5 = _pycec.CEC_USER_CONTROL_CODE_NUMBER5
CEC_USER_CONTROL_CODE_NUMBER6 = _pycec.CEC_USER_CONTROL_CODE_NUMBER6
CEC_USER_CONTROL_CODE_NUMBER7 = _pycec.CEC_USER_CONTROL_CODE_NUMBER7
CEC_USER_CONTROL_CODE_NUMBER8 = _pycec.CEC_USER_CONTROL_CODE_NUMBER8
CEC_USER_CONTROL_CODE_NUMBER9 = _pycec.CEC_USER_CONTROL_CODE_NUMBER9
CEC_USER_CONTROL_CODE_DOT = _pycec.CEC_USER_CONTROL_CODE_DOT
CEC_USER_CONTROL_CODE_ENTER = _pycec.CEC_USER_CONTROL_CODE_ENTER
CEC_USER_CONTROL_CODE_CLEAR = _pycec.CEC_USER_CONTROL_CODE_CLEAR
CEC_USER_CONTROL_CODE_NEXT_FAVORITE = _pycec.CEC_USER_CONTROL_CODE_NEXT_FAVORITE
CEC_USER_CONTROL_CODE_CHANNEL_UP = _pycec.CEC_USER_CONTROL_CODE_CHANNEL_UP
CEC_USER_CONTROL_CODE_CHANNEL_DOWN = _pycec.CEC_USER_CONTROL_CODE_CHANNEL_DOWN
CEC_USER_CONTROL_CODE_PREVIOUS_CHANNEL = _pycec.CEC_USER_CONTROL_CODE_PREVIOUS_CHANNEL
CEC_USER_CONTROL_CODE_SOUND_SELECT = _pycec.CEC_USER_CONTROL_CODE_SOUND_SELECT
CEC_USER_CONTROL_CODE_INPUT_SELECT = _pycec.CEC_USER_CONTROL_CODE_INPUT_SELECT
CEC_USER_CONTROL_CODE_DISPLAY_INFORMATION = _pycec.CEC_USER_CONTROL_CODE_DISPLAY_INFORMATION
CEC_USER_CONTROL_CODE_HELP = _pycec.CEC_USER_CONTROL_CODE_HELP
CEC_USER_CONTROL_CODE_PAGE_UP = _pycec.CEC_USER_CONTROL_CODE_PAGE_UP
CEC_USER_CONTROL_CODE_PAGE_DOWN = _pycec.CEC_USER_CONTROL_CODE_PAGE_DOWN
CEC_USER_CONTROL_CODE_POWER = _pycec.CEC_USER_CONTROL_CODE_POWER
CEC_USER_CONTROL_CODE_VOLUME_UP = _pycec.CEC_USER_CONTROL_CODE_VOLUME_UP
CEC_USER_CONTROL_CODE_VOLUME_DOWN = _pycec.CEC_USER_CONTROL_CODE_VOLUME_DOWN
CEC_USER_CONTROL_CODE_MUTE = _pycec.CEC_USER_CONTROL_CODE_MUTE
CEC_USER_CONTROL_CODE_PLAY = _pycec.CEC_USER_CONTROL_CODE_PLAY
CEC_USER_CONTROL_CODE_STOP = _pycec.CEC_USER_CONTROL_CODE_STOP
CEC_USER_CONTROL_CODE_PAUSE = _pycec.CEC_USER_CONTROL_CODE_PAUSE
CEC_USER_CONTROL_CODE_RECORD = _pycec.CEC_USER_CONTROL_CODE_RECORD
CEC_USER_CONTROL_CODE_REWIND = _pycec.CEC_USER_CONTROL_CODE_REWIND
CEC_USER_CONTROL_CODE_FAST_FORWARD = _pycec.CEC_USER_CONTROL_CODE_FAST_FORWARD
CEC_USER_CONTROL_CODE_EJECT = _pycec.CEC_USER_CONTROL_CODE_EJECT
CEC_USER_CONTROL_CODE_FORWARD = _pycec.CEC_USER_CONTROL_CODE_FORWARD
CEC_USER_CONTROL_CODE_BACKWARD = _pycec.CEC_USER_CONTROL_CODE_BACKWARD
CEC_USER_CONTROL_CODE_STOP_RECORD = _pycec.CEC_USER_CONTROL_CODE_STOP_RECORD
CEC_USER_CONTROL_CODE_PAUSE_RECORD = _pycec.CEC_USER_CONTROL_CODE_PAUSE_RECORD
CEC_USER_CONTROL_CODE_ANGLE = _pycec.CEC_USER_CONTROL_CODE_ANGLE
CEC_USER_CONTROL_CODE_SUB_PICTURE = _pycec.CEC_USER_CONTROL_CODE_SUB_PICTURE
CEC_USER_CONTROL_CODE_VIDEO_ON_DEMAND = _pycec.CEC_USER_CONTROL_CODE_VIDEO_ON_DEMAND
CEC_USER_CONTROL_CODE_ELECTRONIC_PROGRAM_GUIDE = _pycec.CEC_USER_CONTROL_CODE_ELECTRONIC_PROGRAM_GUIDE
CEC_USER_CONTROL_CODE_TIMER_PROGRAMMING = _pycec.CEC_USER_CONTROL_CODE_TIMER_PROGRAMMING
CEC_USER_CONTROL_CODE_INITIAL_CONFIGURATION = _pycec.CEC_USER_CONTROL_CODE_INITIAL_CONFIGURATION
CEC_USER_CONTROL_CODE_SELECT_BROADCAST_TYPE = _pycec.CEC_USER_CONTROL_CODE_SELECT_BROADCAST_TYPE
CEC_USER_CONTROL_CODE_SELECT_SOUND_PRESENTATION = _pycec.CEC_USER_CONTROL_CODE_SELECT_SOUND_PRESENTATION
CEC_USER_CONTROL_CODE_PLAY_FUNCTION = _pycec.CEC_USER_CONTROL_CODE_PLAY_FUNCTION
CEC_USER_CONTROL_CODE_PAUSE_PLAY_FUNCTION = _pycec.CEC_USER_CONTROL_CODE_PAUSE_PLAY_FUNCTION
CEC_USER_CONTROL_CODE_RECORD_FUNCTION = _pycec.CEC_USER_CONTROL_CODE_RECORD_FUNCTION
CEC_USER_CONTROL_CODE_PAUSE_RECORD_FUNCTION = _pycec.CEC_USER_CONTROL_CODE_PAUSE_RECORD_FUNCTION
CEC_USER_CONTROL_CODE_STOP_FUNCTION = _pycec.CEC_USER_CONTROL_CODE_STOP_FUNCTION
CEC_USER_CONTROL_CODE_MUTE_FUNCTION = _pycec.CEC_USER_CONTROL_CODE_MUTE_FUNCTION
CEC_USER_CONTROL_CODE_RESTORE_VOLUME_FUNCTION = _pycec.CEC_USER_CONTROL_CODE_RESTORE_VOLUME_FUNCTION
CEC_USER_CONTROL_CODE_TUNE_FUNCTION = _pycec.CEC_USER_CONTROL_CODE_TUNE_FUNCTION
CEC_USER_CONTROL_CODE_SELECT_MEDIA_FUNCTION = _pycec.CEC_USER_CONTROL_CODE_SELECT_MEDIA_FUNCTION
CEC_USER_CONTROL_CODE_SELECT_AV_INPUT_FUNCTION = _pycec.CEC_USER_CONTROL_CODE_SELECT_AV_INPUT_FUNCTION
CEC_USER_CONTROL_CODE_SELECT_AUDIO_INPUT_FUNCTION = _pycec.CEC_USER_CONTROL_CODE_SELECT_AUDIO_INPUT_FUNCTION
CEC_USER_CONTROL_CODE_POWER_TOGGLE_FUNCTION = _pycec.CEC_USER_CONTROL_CODE_POWER_TOGGLE_FUNCTION
CEC_USER_CONTROL_CODE_POWER_OFF_FUNCTION = _pycec.CEC_USER_CONTROL_CODE_POWER_OFF_FUNCTION
CEC_USER_CONTROL_CODE_POWER_ON_FUNCTION = _pycec.CEC_USER_CONTROL_CODE_POWER_ON_FUNCTION
CEC_USER_CONTROL_CODE_F1_BLUE = _pycec.CEC_USER_CONTROL_CODE_F1_BLUE
CEC_USER_CONTROL_CODE_F2_RED = _pycec.CEC_USER_CONTROL_CODE_F2_RED
CEC_USER_CONTROL_CODE_F3_GREEN = _pycec.CEC_USER_CONTROL_CODE_F3_GREEN
CEC_USER_CONTROL_CODE_F4_YELLOW = _pycec.CEC_USER_CONTROL_CODE_F4_YELLOW
CEC_USER_CONTROL_CODE_F5 = _pycec.CEC_USER_CONTROL_CODE_F5
CEC_USER_CONTROL_CODE_DATA = _pycec.CEC_USER_CONTROL_CODE_DATA
CEC_USER_CONTROL_CODE_AN_RETURN = _pycec.CEC_USER_CONTROL_CODE_AN_RETURN
CEC_USER_CONTROL_CODE_AN_CHANNELS_LIST = _pycec.CEC_USER_CONTROL_CODE_AN_CHANNELS_LIST
CEC_USER_CONTROL_CODE_MAX = _pycec.CEC_USER_CONTROL_CODE_MAX
CEC_USER_CONTROL_CODE_UNKNOWN = _pycec.CEC_USER_CONTROL_CODE_UNKNOWN
CECDEVICE_UNKNOWN = _pycec.CECDEVICE_UNKNOWN
CECDEVICE_TV = _pycec.CECDEVICE_TV
CECDEVICE_RECORDINGDEVICE1 = _pycec.CECDEVICE_RECORDINGDEVICE1
CECDEVICE_RECORDINGDEVICE2 = _pycec.CECDEVICE_RECORDINGDEVICE2
CECDEVICE_TUNER1 = _pycec.CECDEVICE_TUNER1
CECDEVICE_PLAYBACKDEVICE1 = _pycec.CECDEVICE_PLAYBACKDEVICE1
CECDEVICE_AUDIOSYSTEM = _pycec.CECDEVICE_AUDIOSYSTEM
CECDEVICE_TUNER2 = _pycec.CECDEVICE_TUNER2
CECDEVICE_TUNER3 = _pycec.CECDEVICE_TUNER3
CECDEVICE_PLAYBACKDEVICE2 = _pycec.CECDEVICE_PLAYBACKDEVICE2
CECDEVICE_RECORDINGDEVICE3 = _pycec.CECDEVICE_RECORDINGDEVICE3
CECDEVICE_TUNER4 = _pycec.CECDEVICE_TUNER4
CECDEVICE_PLAYBACKDEVICE3 = _pycec.CECDEVICE_PLAYBACKDEVICE3
CECDEVICE_RESERVED1 = _pycec.CECDEVICE_RESERVED1
CECDEVICE_RESERVED2 = _pycec.CECDEVICE_RESERVED2
CECDEVICE_FREEUSE = _pycec.CECDEVICE_FREEUSE
CECDEVICE_UNREGISTERED = _pycec.CECDEVICE_UNREGISTERED
CECDEVICE_BROADCAST = _pycec.CECDEVICE_BROADCAST
CEC_OPCODE_ACTIVE_SOURCE = _pycec.CEC_OPCODE_ACTIVE_SOURCE
CEC_OPCODE_IMAGE_VIEW_ON = _pycec.CEC_OPCODE_IMAGE_VIEW_ON
CEC_OPCODE_TEXT_VIEW_ON = _pycec.CEC_OPCODE_TEXT_VIEW_ON
CEC_OPCODE_INACTIVE_SOURCE = _pycec.CEC_OPCODE_INACTIVE_SOURCE
CEC_OPCODE_REQUEST_ACTIVE_SOURCE = _pycec.CEC_OPCODE_REQUEST_ACTIVE_SOURCE
CEC_OPCODE_ROUTING_CHANGE = _pycec.CEC_OPCODE_ROUTING_CHANGE
CEC_OPCODE_ROUTING_INFORMATION = _pycec.CEC_OPCODE_ROUTING_INFORMATION
CEC_OPCODE_SET_STREAM_PATH = _pycec.CEC_OPCODE_SET_STREAM_PATH
CEC_OPCODE_STANDBY = _pycec.CEC_OPCODE_STANDBY
CEC_OPCODE_RECORD_OFF = _pycec.CEC_OPCODE_RECORD_OFF
CEC_OPCODE_RECORD_ON = _pycec.CEC_OPCODE_RECORD_ON
CEC_OPCODE_RECORD_STATUS = _pycec.CEC_OPCODE_RECORD_STATUS
CEC_OPCODE_RECORD_TV_SCREEN = _pycec.CEC_OPCODE_RECORD_TV_SCREEN
CEC_OPCODE_CLEAR_ANALOGUE_TIMER = _pycec.CEC_OPCODE_CLEAR_ANALOGUE_TIMER
CEC_OPCODE_CLEAR_DIGITAL_TIMER = _pycec.CEC_OPCODE_CLEAR_DIGITAL_TIMER
CEC_OPCODE_CLEAR_EXTERNAL_TIMER = _pycec.CEC_OPCODE_CLEAR_EXTERNAL_TIMER
CEC_OPCODE_SET_ANALOGUE_TIMER = _pycec.CEC_OPCODE_SET_ANALOGUE_TIMER
CEC_OPCODE_SET_DIGITAL_TIMER = _pycec.CEC_OPCODE_SET_DIGITAL_TIMER
CEC_OPCODE_SET_EXTERNAL_TIMER = _pycec.CEC_OPCODE_SET_EXTERNAL_TIMER
CEC_OPCODE_SET_TIMER_PROGRAM_TITLE = _pycec.CEC_OPCODE_SET_TIMER_PROGRAM_TITLE
CEC_OPCODE_TIMER_CLEARED_STATUS = _pycec.CEC_OPCODE_TIMER_CLEARED_STATUS
CEC_OPCODE_TIMER_STATUS = _pycec.CEC_OPCODE_TIMER_STATUS
CEC_OPCODE_CEC_VERSION = _pycec.CEC_OPCODE_CEC_VERSION
CEC_OPCODE_GET_CEC_VERSION = _pycec.CEC_OPCODE_GET_CEC_VERSION
CEC_OPCODE_GIVE_PHYSICAL_ADDRESS = _pycec.CEC_OPCODE_GIVE_PHYSICAL_ADDRESS
CEC_OPCODE_GET_MENU_LANGUAGE = _pycec.CEC_OPCODE_GET_MENU_LANGUAGE
CEC_OPCODE_REPORT_PHYSICAL_ADDRESS = _pycec.CEC_OPCODE_REPORT_PHYSICAL_ADDRESS
CEC_OPCODE_SET_MENU_LANGUAGE = _pycec.CEC_OPCODE_SET_MENU_LANGUAGE
CEC_OPCODE_DECK_CONTROL = _pycec.CEC_OPCODE_DECK_CONTROL
CEC_OPCODE_DECK_STATUS = _pycec.CEC_OPCODE_DECK_STATUS
CEC_OPCODE_GIVE_DECK_STATUS = _pycec.CEC_OPCODE_GIVE_DECK_STATUS
CEC_OPCODE_PLAY = _pycec.CEC_OPCODE_PLAY
CEC_OPCODE_GIVE_TUNER_DEVICE_STATUS = _pycec.CEC_OPCODE_GIVE_TUNER_DEVICE_STATUS
CEC_OPCODE_SELECT_ANALOGUE_SERVICE = _pycec.CEC_OPCODE_SELECT_ANALOGUE_SERVICE
CEC_OPCODE_SELECT_DIGITAL_SERVICE = _pycec.CEC_OPCODE_SELECT_DIGITAL_SERVICE
CEC_OPCODE_TUNER_DEVICE_STATUS = _pycec.CEC_OPCODE_TUNER_DEVICE_STATUS
CEC_OPCODE_TUNER_STEP_DECREMENT = _pycec.CEC_OPCODE_TUNER_STEP_DECREMENT
CEC_OPCODE_TUNER_STEP_INCREMENT = _pycec.CEC_OPCODE_TUNER_STEP_INCREMENT
CEC_OPCODE_DEVICE_VENDOR_ID = _pycec.CEC_OPCODE_DEVICE_VENDOR_ID
CEC_OPCODE_GIVE_DEVICE_VENDOR_ID = _pycec.CEC_OPCODE_GIVE_DEVICE_VENDOR_ID
CEC_OPCODE_VENDOR_COMMAND = _pycec.CEC_OPCODE_VENDOR_COMMAND
CEC_OPCODE_VENDOR_COMMAND_WITH_ID = _pycec.CEC_OPCODE_VENDOR_COMMAND_WITH_ID
CEC_OPCODE_VENDOR_REMOTE_BUTTON_DOWN = _pycec.CEC_OPCODE_VENDOR_REMOTE_BUTTON_DOWN
CEC_OPCODE_VENDOR_REMOTE_BUTTON_UP = _pycec.CEC_OPCODE_VENDOR_REMOTE_BUTTON_UP
CEC_OPCODE_SET_OSD_STRING = _pycec.CEC_OPCODE_SET_OSD_STRING
CEC_OPCODE_GIVE_OSD_NAME = _pycec.CEC_OPCODE_GIVE_OSD_NAME
CEC_OPCODE_SET_OSD_NAME = _pycec.CEC_OPCODE_SET_OSD_NAME
CEC_OPCODE_MENU_REQUEST = _pycec.CEC_OPCODE_MENU_REQUEST
CEC_OPCODE_MENU_STATUS = _pycec.CEC_OPCODE_MENU_STATUS
CEC_OPCODE_USER_CONTROL_PRESSED = _pycec.CEC_OPCODE_USER_CONTROL_PRESSED
CEC_OPCODE_USER_CONTROL_RELEASE = _pycec.CEC_OPCODE_USER_CONTROL_RELEASE
CEC_OPCODE_GIVE_DEVICE_POWER_STATUS = _pycec.CEC_OPCODE_GIVE_DEVICE_POWER_STATUS
CEC_OPCODE_REPORT_POWER_STATUS = _pycec.CEC_OPCODE_REPORT_POWER_STATUS
CEC_OPCODE_FEATURE_ABORT = _pycec.CEC_OPCODE_FEATURE_ABORT
CEC_OPCODE_ABORT = _pycec.CEC_OPCODE_ABORT
CEC_OPCODE_GIVE_AUDIO_STATUS = _pycec.CEC_OPCODE_GIVE_AUDIO_STATUS
CEC_OPCODE_GIVE_SYSTEM_AUDIO_MODE_STATUS = _pycec.CEC_OPCODE_GIVE_SYSTEM_AUDIO_MODE_STATUS
CEC_OPCODE_REPORT_AUDIO_STATUS = _pycec.CEC_OPCODE_REPORT_AUDIO_STATUS
CEC_OPCODE_SET_SYSTEM_AUDIO_MODE = _pycec.CEC_OPCODE_SET_SYSTEM_AUDIO_MODE
CEC_OPCODE_SYSTEM_AUDIO_MODE_REQUEST = _pycec.CEC_OPCODE_SYSTEM_AUDIO_MODE_REQUEST
CEC_OPCODE_SYSTEM_AUDIO_MODE_STATUS = _pycec.CEC_OPCODE_SYSTEM_AUDIO_MODE_STATUS
CEC_OPCODE_SET_AUDIO_RATE = _pycec.CEC_OPCODE_SET_AUDIO_RATE
CEC_OPCODE_REPORT_SHORT_AUDIO_DESCRIPTORS = _pycec.CEC_OPCODE_REPORT_SHORT_AUDIO_DESCRIPTORS
CEC_OPCODE_REQUEST_SHORT_AUDIO_DESCRIPTORS = _pycec.CEC_OPCODE_REQUEST_SHORT_AUDIO_DESCRIPTORS
CEC_OPCODE_START_ARC = _pycec.CEC_OPCODE_START_ARC
CEC_OPCODE_REPORT_ARC_STARTED = _pycec.CEC_OPCODE_REPORT_ARC_STARTED
CEC_OPCODE_REPORT_ARC_ENDED = _pycec.CEC_OPCODE_REPORT_ARC_ENDED
CEC_OPCODE_REQUEST_ARC_START = _pycec.CEC_OPCODE_REQUEST_ARC_START
CEC_OPCODE_REQUEST_ARC_END = _pycec.CEC_OPCODE_REQUEST_ARC_END
CEC_OPCODE_END_ARC = _pycec.CEC_OPCODE_END_ARC
CEC_OPCODE_CDC = _pycec.CEC_OPCODE_CDC
CEC_OPCODE_NONE = _pycec.CEC_OPCODE_NONE
CEC_LOG_ERROR = _pycec.CEC_LOG_ERROR
CEC_LOG_WARNING = _pycec.CEC_LOG_WARNING
CEC_LOG_NOTICE = _pycec.CEC_LOG_NOTICE
CEC_LOG_TRAFFIC = _pycec.CEC_LOG_TRAFFIC
CEC_LOG_DEBUG = _pycec.CEC_LOG_DEBUG
CEC_LOG_ALL = _pycec.CEC_LOG_ALL
CEC_DEVICE_STATUS_UNKNOWN = _pycec.CEC_DEVICE_STATUS_UNKNOWN
CEC_DEVICE_STATUS_PRESENT = _pycec.CEC_DEVICE_STATUS_PRESENT
CEC_DEVICE_STATUS_NOT_PRESENT = _pycec.CEC_DEVICE_STATUS_NOT_PRESENT
CEC_DEVICE_STATUS_HANDLED_BY_LIBCEC = _pycec.CEC_DEVICE_STATUS_HANDLED_BY_LIBCEC
CEC_VENDOR_TOSHIBA = _pycec.CEC_VENDOR_TOSHIBA
CEC_VENDOR_SAMSUNG = _pycec.CEC_VENDOR_SAMSUNG
CEC_VENDOR_DENON = _pycec.CEC_VENDOR_DENON
CEC_VENDOR_MARANTZ = _pycec.CEC_VENDOR_MARANTZ
CEC_VENDOR_LOEWE = _pycec.CEC_VENDOR_LOEWE
CEC_VENDOR_ONKYO = _pycec.CEC_VENDOR_ONKYO
CEC_VENDOR_MEDION = _pycec.CEC_VENDOR_MEDION
CEC_VENDOR_TOSHIBA2 = _pycec.CEC_VENDOR_TOSHIBA2
CEC_VENDOR_APPLE = _pycec.CEC_VENDOR_APPLE
CEC_VENDOR_PULSE_EIGHT = _pycec.CEC_VENDOR_PULSE_EIGHT
CEC_VENDOR_HARMAN_KARDON2 = _pycec.CEC_VENDOR_HARMAN_KARDON2
CEC_VENDOR_GOOGLE = _pycec.CEC_VENDOR_GOOGLE
CEC_VENDOR_AKAI = _pycec.CEC_VENDOR_AKAI
CEC_VENDOR_AOC = _pycec.CEC_VENDOR_AOC
CEC_VENDOR_PANASONIC = _pycec.CEC_VENDOR_PANASONIC
CEC_VENDOR_PHILIPS = _pycec.CEC_VENDOR_PHILIPS
CEC_VENDOR_DAEWOO = _pycec.CEC_VENDOR_DAEWOO
CEC_VENDOR_YAMAHA = _pycec.CEC_VENDOR_YAMAHA
CEC_VENDOR_GRUNDIG = _pycec.CEC_VENDOR_GRUNDIG
CEC_VENDOR_PIONEER = _pycec.CEC_VENDOR_PIONEER
CEC_VENDOR_LG = _pycec.CEC_VENDOR_LG
CEC_VENDOR_SHARP = _pycec.CEC_VENDOR_SHARP
CEC_VENDOR_SONY = _pycec.CEC_VENDOR_SONY
CEC_VENDOR_TEUFEL = _pycec.CEC_VENDOR_TEUFEL
CEC_VENDOR_BROADCOM = _pycec.CEC_VENDOR_BROADCOM
CEC_VENDOR_SHARP2 = _pycec.CEC_VENDOR_SHARP2
CEC_VENDOR_VIZIO = _pycec.CEC_VENDOR_VIZIO
CEC_VENDOR_BENQ = _pycec.CEC_VENDOR_BENQ
CEC_VENDOR_HARMAN_KARDON = _pycec.CEC_VENDOR_HARMAN_KARDON
CEC_VENDOR_UNKNOWN = _pycec.CEC_VENDOR_UNKNOWN
ADAPTERTYPE_UNKNOWN = _pycec.ADAPTERTYPE_UNKNOWN
ADAPTERTYPE_P8_EXTERNAL = _pycec.ADAPTERTYPE_P8_EXTERNAL
ADAPTERTYPE_P8_DAUGHTERBOARD = _pycec.ADAPTERTYPE_P8_DAUGHTERBOARD
ADAPTERTYPE_RPI = _pycec.ADAPTERTYPE_RPI
ADAPTERTYPE_TDA995x = _pycec.ADAPTERTYPE_TDA995x
ADAPTERTYPE_EXYNOS = _pycec.ADAPTERTYPE_EXYNOS
ADAPTERTYPE_LINUX = _pycec.ADAPTERTYPE_LINUX
ADAPTERTYPE_AOCEC = _pycec.ADAPTERTYPE_AOCEC
ADAPTERTYPE_IMX = _pycec.ADAPTERTYPE_IMX
ADAPTERTYPE_TEGRA = _pycec.ADAPTERTYPE_TEGRA
LIBCEC_VERSION_CURRENT = _pycec.LIBCEC_VERSION_CURRENT
class AdapterDescriptor(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _pycec.AdapterDescriptor_swiginit(self, _pycec.new_AdapterDescriptor(*args))
    strComPath = property(_pycec.AdapterDescriptor_strComPath_get, _pycec.AdapterDescriptor_strComPath_set)
    strComName = property(_pycec.AdapterDescriptor_strComName_get, _pycec.AdapterDescriptor_strComName_set)
    iVendorId = property(_pycec.AdapterDescriptor_iVendorId_get, _pycec.AdapterDescriptor_iVendorId_set)
    iProductId = property(_pycec.AdapterDescriptor_iProductId_get, _pycec.AdapterDescriptor_iProductId_set)
    iFirmwareVersion = property(_pycec.AdapterDescriptor_iFirmwareVersion_get, _pycec.AdapterDescriptor_iFirmwareVersion_set)
    iPhysicalAddress = property(_pycec.AdapterDescriptor_iPhysicalAddress_get, _pycec.AdapterDescriptor_iPhysicalAddress_set)
    iFirmwareBuildDate = property(_pycec.AdapterDescriptor_iFirmwareBuildDate_get, _pycec.AdapterDescriptor_iFirmwareBuildDate_set)
    adapterType = property(_pycec.AdapterDescriptor_adapterType_get, _pycec.AdapterDescriptor_adapterType_set)
    __swig_destroy__ = _pycec.delete_AdapterDescriptor

# Register AdapterDescriptor in _pycec:
_pycec.AdapterDescriptor_swigregister(AdapterDescriptor)
class cec_datapacket(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr
    data = property(_pycec.cec_datapacket_data_get, _pycec.cec_datapacket_data_set)
    size = property(_pycec.cec_datapacket_size_get, _pycec.cec_datapacket_size_set)

    def __eq__(self, packet):
        return _pycec.cec_datapacket___eq__(self, packet)

    def IsEmpty(self):
        return _pycec.cec_datapacket_IsEmpty(self)

    def IsFull(self):
        return _pycec.cec_datapacket_IsFull(self)

    def At(self, pos):
        return _pycec.cec_datapacket_At(self, pos)

    def Shift(self, iShiftBy):
        return _pycec.cec_datapacket_Shift(self, iShiftBy)

    def PushBack(self, add):
        return _pycec.cec_datapacket_PushBack(self, add)

    def Clear(self):
        return _pycec.cec_datapacket_Clear(self)

    def __getitem__(self, pos):
        return _pycec.cec_datapacket___getitem__(self, pos)

    def __init__(self):
        _pycec.cec_datapacket_swiginit(self, _pycec.new_cec_datapacket())
    __swig_destroy__ = _pycec.delete_cec_datapacket

# Register cec_datapacket in _pycec:
_pycec.cec_datapacket_swigregister(cec_datapacket)
class cec_command(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr
    initiator = property(_pycec.cec_command_initiator_get, _pycec.cec_command_initiator_set)
    destination = property(_pycec.cec_command_destination_get, _pycec.cec_command_destination_set)
    ack = property(_pycec.cec_command_ack_get, _pycec.cec_command_ack_set)
    eom = property(_pycec.cec_command_eom_get, _pycec.cec_command_eom_set)
    opcode = property(_pycec.cec_command_opcode_get, _pycec.cec_command_opcode_set)
    parameters = property(_pycec.cec_command_parameters_get, _pycec.cec_command_parameters_set)
    opcode_set = property(_pycec.cec_command_opcode_set_get, _pycec.cec_command_opcode_set_set)
    transmit_timeout = property(_pycec.cec_command_transmit_timeout_get, _pycec.cec_command_transmit_timeout_set)

    def __init__(self):
        _pycec.cec_command_swiginit(self, _pycec.new_cec_command())

    def Size(self):
        return _pycec.cec_command_Size(self)

    @staticmethod
    def Format(command, initiator, destination, opcode, timeout=1000):
        return _pycec.cec_command_Format(command, initiator, destination, opcode, timeout)

    def PushBack(self, data):
        return _pycec.cec_command_PushBack(self, data)

    def Clear(self):
        return _pycec.cec_command_Clear(self)

    @staticmethod
    def GetResponseOpcode(opcode):
        return _pycec.cec_command_GetResponseOpcode(opcode)

    def PushArray(self, len, data):
        return _pycec.cec_command_PushArray(self, len, data)
    __swig_destroy__ = _pycec.delete_cec_command

# Register cec_command in _pycec:
_pycec.cec_command_swigregister(cec_command)
class cec_device_type_list(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr
    types = property(_pycec.cec_device_type_list_types_get, _pycec.cec_device_type_list_types_set)

    def Clear(self):
        return _pycec.cec_device_type_list_Clear(self)

    def Add(self, type):
        return _pycec.cec_device_type_list_Add(self, type)

    def IsSet(self, type):
        return _pycec.cec_device_type_list_IsSet(self, type)

    def IsEmpty(self):
        return _pycec.cec_device_type_list_IsEmpty(self)

    def __eq__(self, other):
        return _pycec.cec_device_type_list___eq__(self, other)

    def __ne__(self, other):
        return _pycec.cec_device_type_list___ne__(self, other)

    def __getitem__(self, pos):
        return _pycec.cec_device_type_list___getitem__(self, pos)

    def __init__(self):
        _pycec.cec_device_type_list_swiginit(self, _pycec.new_cec_device_type_list())
    __swig_destroy__ = _pycec.delete_cec_device_type_list

# Register cec_device_type_list in _pycec:
_pycec.cec_device_type_list_swigregister(cec_device_type_list)
class cec_logical_addresses(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr
    primary = property(_pycec.cec_logical_addresses_primary_get, _pycec.cec_logical_addresses_primary_set)
    addresses = property(_pycec.cec_logical_addresses_addresses_get, _pycec.cec_logical_addresses_addresses_set)

    def Clear(self):
        return _pycec.cec_logical_addresses_Clear(self)

    def IsEmpty(self):
        return _pycec.cec_logical_addresses_IsEmpty(self)

    def AckMask(self):
        return _pycec.cec_logical_addresses_AckMask(self)

    def Set(self, address):
        return _pycec.cec_logical_addresses_Set(self, address)

    def Unset(self, address):
        return _pycec.cec_logical_addresses_Unset(self, address)

    def IsSet(self, address):
        return _pycec.cec_logical_addresses_IsSet(self, address)

    def __eq__(self, other):
        return _pycec.cec_logical_addresses___eq__(self, other)

    def __ne__(self, other):
        return _pycec.cec_logical_addresses___ne__(self, other)

    def __getitem__(self, pos):
        return _pycec.cec_logical_addresses___getitem__(self, pos)

    def __init__(self):
        _pycec.cec_logical_addresses_swiginit(self, _pycec.new_cec_logical_addresses())
    __swig_destroy__ = _pycec.delete_cec_logical_addresses

# Register cec_logical_addresses in _pycec:
_pycec.cec_logical_addresses_swigregister(cec_logical_addresses)
CEC_ALERT_SERVICE_DEVICE = _pycec.CEC_ALERT_SERVICE_DEVICE
CEC_ALERT_CONNECTION_LOST = _pycec.CEC_ALERT_CONNECTION_LOST
CEC_ALERT_PERMISSION_ERROR = _pycec.CEC_ALERT_PERMISSION_ERROR
CEC_ALERT_PORT_BUSY = _pycec.CEC_ALERT_PORT_BUSY
CEC_ALERT_PHYSICAL_ADDRESS_ERROR = _pycec.CEC_ALERT_PHYSICAL_ADDRESS_ERROR
CEC_ALERT_TV_POLL_FAILED = _pycec.CEC_ALERT_TV_POLL_FAILED
CEC_PARAMETER_TYPE_STRING = _pycec.CEC_PARAMETER_TYPE_STRING
CEC_PARAMETER_TYPE_UNKOWN = _pycec.CEC_PARAMETER_TYPE_UNKOWN
class libcec_parameter(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr
    paramType = property(_pycec.libcec_parameter_paramType_get, _pycec.libcec_parameter_paramType_set)
    paramData = property(_pycec.libcec_parameter_paramData_get, _pycec.libcec_parameter_paramData_set)

    def __init__(self):
        _pycec.libcec_parameter_swiginit(self, _pycec.new_libcec_parameter())
    __swig_destroy__ = _pycec.delete_libcec_parameter

# Register libcec_parameter in _pycec:
_pycec.libcec_parameter_swigregister(libcec_parameter)
class cec_adapter_stats(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr
    tx_ack = property(_pycec.cec_adapter_stats_tx_ack_get, _pycec.cec_adapter_stats_tx_ack_set)
    tx_nack = property(_pycec.cec_adapter_stats_tx_nack_get, _pycec.cec_adapter_stats_tx_nack_set)
    tx_error = property(_pycec.cec_adapter_stats_tx_error_get, _pycec.cec_adapter_stats_tx_error_set)
    rx_total = property(_pycec.cec_adapter_stats_rx_total_get, _pycec.cec_adapter_stats_rx_total_set)
    rx_error = property(_pycec.cec_adapter_stats_rx_error_get, _pycec.cec_adapter_stats_rx_error_set)

    def __init__(self):
        _pycec.cec_adapter_stats_swiginit(self, _pycec.new_cec_adapter_stats())
    __swig_destroy__ = _pycec.delete_cec_adapter_stats

# Register cec_adapter_stats in _pycec:
_pycec.cec_adapter_stats_swigregister(cec_adapter_stats)
LIBCEC_OSD_NAME_SIZE = _pycec.LIBCEC_OSD_NAME_SIZE
class libcec_configuration(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr
    clientVersion = property(_pycec.libcec_configuration_clientVersion_get, _pycec.libcec_configuration_clientVersion_set)
    strDeviceName = property(_pycec.libcec_configuration_strDeviceName_get, _pycec.libcec_configuration_strDeviceName_set)
    deviceTypes = property(_pycec.libcec_configuration_deviceTypes_get, _pycec.libcec_configuration_deviceTypes_set)
    bAutodetectAddress = property(_pycec.libcec_configuration_bAutodetectAddress_get, _pycec.libcec_configuration_bAutodetectAddress_set)
    iPhysicalAddress = property(_pycec.libcec_configuration_iPhysicalAddress_get, _pycec.libcec_configuration_iPhysicalAddress_set)
    baseDevice = property(_pycec.libcec_configuration_baseDevice_get, _pycec.libcec_configuration_baseDevice_set)
    iHDMIPort = property(_pycec.libcec_configuration_iHDMIPort_get, _pycec.libcec_configuration_iHDMIPort_set)
    tvVendor = property(_pycec.libcec_configuration_tvVendor_get, _pycec.libcec_configuration_tvVendor_set)
    wakeDevices = property(_pycec.libcec_configuration_wakeDevices_get, _pycec.libcec_configuration_wakeDevices_set)
    powerOffDevices = property(_pycec.libcec_configuration_powerOffDevices_get, _pycec.libcec_configuration_powerOffDevices_set)
    serverVersion = property(_pycec.libcec_configuration_serverVersion_get, _pycec.libcec_configuration_serverVersion_set)
    bGetSettingsFromROM = property(_pycec.libcec_configuration_bGetSettingsFromROM_get, _pycec.libcec_configuration_bGetSettingsFromROM_set)
    bActivateSource = property(_pycec.libcec_configuration_bActivateSource_get, _pycec.libcec_configuration_bActivateSource_set)
    bPowerOffOnStandby = property(_pycec.libcec_configuration_bPowerOffOnStandby_get, _pycec.libcec_configuration_bPowerOffOnStandby_set)
    logicalAddresses = property(_pycec.libcec_configuration_logicalAddresses_get, _pycec.libcec_configuration_logicalAddresses_set)
    iFirmwareVersion = property(_pycec.libcec_configuration_iFirmwareVersion_get, _pycec.libcec_configuration_iFirmwareVersion_set)
    strDeviceLanguage = property(_pycec.libcec_configuration_strDeviceLanguage_get, _pycec.libcec_configuration_strDeviceLanguage_set)
    iFirmwareBuildDate = property(_pycec.libcec_configuration_iFirmwareBuildDate_get, _pycec.libcec_configuration_iFirmwareBuildDate_set)
    bMonitorOnly = property(_pycec.libcec_configuration_bMonitorOnly_get, _pycec.libcec_configuration_bMonitorOnly_set)
    cecVersion = property(_pycec.libcec_configuration_cecVersion_get, _pycec.libcec_configuration_cecVersion_set)
    adapterType = property(_pycec.libcec_configuration_adapterType_get, _pycec.libcec_configuration_adapterType_set)
    comboKey = property(_pycec.libcec_configuration_comboKey_get, _pycec.libcec_configuration_comboKey_set)
    iComboKeyTimeoutMs = property(_pycec.libcec_configuration_iComboKeyTimeoutMs_get, _pycec.libcec_configuration_iComboKeyTimeoutMs_set)
    iButtonRepeatRateMs = property(_pycec.libcec_configuration_iButtonRepeatRateMs_get, _pycec.libcec_configuration_iButtonRepeatRateMs_set)
    iButtonReleaseDelayMs = property(_pycec.libcec_configuration_iButtonReleaseDelayMs_get, _pycec.libcec_configuration_iButtonReleaseDelayMs_set)
    iDoubleTapTimeoutMs = property(_pycec.libcec_configuration_iDoubleTapTimeoutMs_get, _pycec.libcec_configuration_iDoubleTapTimeoutMs_set)
    bAutoWakeAVR = property(_pycec.libcec_configuration_bAutoWakeAVR_get, _pycec.libcec_configuration_bAutoWakeAVR_set)

    def __init__(self):
        _pycec.libcec_configuration_swiginit(self, _pycec.new_libcec_configuration())

    def __eq__(self, other):
        return _pycec.libcec_configuration___eq__(self, other)

    def __ne__(self, other):
        return _pycec.libcec_configuration___ne__(self, other)

    def Clear(self):
        return _pycec.libcec_configuration_Clear(self)
    __swig_destroy__ = _pycec.delete_libcec_configuration

    def SetLogCallback(self, pyfunc):
        return _pycec.libcec_configuration_SetLogCallback(self, pyfunc)

    def SetKeyPressCallback(self, pyfunc):
        return _pycec.libcec_configuration_SetKeyPressCallback(self, pyfunc)

    def SetCommandCallback(self, pyfunc):
        return _pycec.libcec_configuration_SetCommandCallback(self, pyfunc)

    def SetMenuStateCallback(self, pyfunc):
        return _pycec.libcec_configuration_SetMenuStateCallback(self, pyfunc)

    def SetSourceActivatedCallback(self, pyfunc):
        return _pycec.libcec_configuration_SetSourceActivatedCallback(self, pyfunc)

    def SetAlertCallback(self, pyfunc):
        return _pycec.libcec_configuration_SetAlertCallback(self, pyfunc)

    def SetConfigurationChangedCallback(self, pyfunc):
        return _pycec.libcec_configuration_SetConfigurationChangedCallback(self, pyfunc)

    def SetCommandHandlerCallback(self, pyfunc):
        return _pycec.libcec_configuration_SetCommandHandlerCallback(self, pyfunc)

    def ClearCallbacks(self):
        return _pycec.libcec_configuration_ClearCallbacks(self)

# Register libcec_configuration in _pycec:
_pycec.libcec_configuration_swigregister(libcec_configuration)
class ICECAdapter(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr

    def Open(self, strPort, iTimeoutMs=10000):
        return _pycec.ICECAdapter_Open(self, strPort, iTimeoutMs)

    def Close(self):
        return _pycec.ICECAdapter_Close(self)

    def PingAdapter(self):
        return _pycec.ICECAdapter_PingAdapter(self)

    def StartBootloader(self):
        return _pycec.ICECAdapter_StartBootloader(self)

    def Transmit(self, data):
        return _pycec.ICECAdapter_Transmit(self, data)

    def SetLogicalAddress(self, *args):
        return _pycec.ICECAdapter_SetLogicalAddress(self, *args)

    def SetPhysicalAddress(self, iPhysicalAddress=4096):
        return _pycec.ICECAdapter_SetPhysicalAddress(self, iPhysicalAddress)

    def PowerOnDevices(self, *args):
        return _pycec.ICECAdapter_PowerOnDevices(self, *args)

    def StandbyDevices(self, *args):
        return _pycec.ICECAdapter_StandbyDevices(self, *args)

    def SetActiveSource(self, *args):
        return _pycec.ICECAdapter_SetActiveSource(self, *args)

    def SetDeckControlMode(self, mode, bSendUpdate=True):
        return _pycec.ICECAdapter_SetDeckControlMode(self, mode, bSendUpdate)

    def SetDeckInfo(self, info, bSendUpdate=True):
        return _pycec.ICECAdapter_SetDeckInfo(self, info, bSendUpdate)

    def SetInactiveView(self):
        return _pycec.ICECAdapter_SetInactiveView(self)

    def SetMenuState(self, state, bSendUpdate=True):
        return _pycec.ICECAdapter_SetMenuState(self, state, bSendUpdate)

    def SetOSDString(self, iLogicalAddress, duration, strMessage):
        return _pycec.ICECAdapter_SetOSDString(self, iLogicalAddress, duration, strMessage)

    def SwitchMonitoring(self, bEnable):
        return _pycec.ICECAdapter_SwitchMonitoring(self, bEnable)

    def GetDeviceCecVersion(self, iLogicalAddress):
        return _pycec.ICECAdapter_GetDeviceCecVersion(self, iLogicalAddress)

    def GetDeviceMenuLanguage(self, iLogicalAddress):
        return _pycec.ICECAdapter_GetDeviceMenuLanguage(self, iLogicalAddress)

    def GetDeviceVendorId(self, iLogicalAddress):
        return _pycec.ICECAdapter_GetDeviceVendorId(self, iLogicalAddress)

    def GetDevicePowerStatus(self, iLogicalAddress):
        return _pycec.ICECAdapter_GetDevicePowerStatus(self, iLogicalAddress)

    def PollDevice(self, iLogicalAddress):
        return _pycec.ICECAdapter_PollDevice(self, iLogicalAddress)

    def GetActiveDevices(self):
        return _pycec.ICECAdapter_GetActiveDevices(self)

    def IsActiveDevice(self, iLogicalAddress):
        return _pycec.ICECAdapter_IsActiveDevice(self, iLogicalAddress)

    def IsActiveDeviceType(self, type):
        return _pycec.ICECAdapter_IsActiveDeviceType(self, type)

    def VolumeUp(self, bSendRelease=True):
        return _pycec.ICECAdapter_VolumeUp(self, bSendRelease)

    def VolumeDown(self, bSendRelease=True):
        return _pycec.ICECAdapter_VolumeDown(self, bSendRelease)

    def SendKeypress(self, iDestination, key, bWait=False):
        return _pycec.ICECAdapter_SendKeypress(self, iDestination, key, bWait)

    def SendKeyRelease(self, iDestination, bWait=False):
        return _pycec.ICECAdapter_SendKeyRelease(self, iDestination, bWait)

    def GetDeviceOSDName(self, iAddress):
        return _pycec.ICECAdapter_GetDeviceOSDName(self, iAddress)

    def GetActiveSource(self):
        return _pycec.ICECAdapter_GetActiveSource(self)

    def IsActiveSource(self, iLogicalAddress):
        return _pycec.ICECAdapter_IsActiveSource(self, iLogicalAddress)

    def SetStreamPath(self, *args):
        return _pycec.ICECAdapter_SetStreamPath(self, *args)

    def GetLogicalAddresses(self):
        return _pycec.ICECAdapter_GetLogicalAddresses(self)

    def GetCurrentConfiguration(self, configuration):
        return _pycec.ICECAdapter_GetCurrentConfiguration(self, configuration)

    def SetConfiguration(self, configuration):
        return _pycec.ICECAdapter_SetConfiguration(self, configuration)

    def RescanActiveDevices(self):
        return _pycec.ICECAdapter_RescanActiveDevices(self)

    def IsLibCECActiveSource(self):
        return _pycec.ICECAdapter_IsLibCECActiveSource(self)

    def GetDeviceInformation(self, strPort, config, iTimeoutMs=10000):
        return _pycec.ICECAdapter_GetDeviceInformation(self, strPort, config, iTimeoutMs)

    def SetHDMIPort(self, iBaseDevice, iPort):
        return _pycec.ICECAdapter_SetHDMIPort(self, iBaseDevice, iPort)

    def GetDevicePhysicalAddress(self, iLogicalAddress):
        return _pycec.ICECAdapter_GetDevicePhysicalAddress(self, iLogicalAddress)

    def GetLibInfo(self):
        return _pycec.ICECAdapter_GetLibInfo(self)

    def InitVideoStandalone(self):
        return _pycec.ICECAdapter_InitVideoStandalone(self)

    def GetAdapterVendorId(self):
        return _pycec.ICECAdapter_GetAdapterVendorId(self)

    def GetAdapterProductId(self):
        return _pycec.ICECAdapter_GetAdapterProductId(self)

    def MenuStateToString(self, state):
        return _pycec.ICECAdapter_MenuStateToString(self, state)

    def CecVersionToString(self, version):
        return _pycec.ICECAdapter_CecVersionToString(self, version)

    def PowerStatusToString(self, status):
        return _pycec.ICECAdapter_PowerStatusToString(self, status)

    def LogicalAddressToString(self, address):
        return _pycec.ICECAdapter_LogicalAddressToString(self, address)

    def DeckControlModeToString(self, mode):
        return _pycec.ICECAdapter_DeckControlModeToString(self, mode)

    def DeckInfoToString(self, status):
        return _pycec.ICECAdapter_DeckInfoToString(self, status)

    def OpcodeToString(self, opcode):
        return _pycec.ICECAdapter_OpcodeToString(self, opcode)

    def ToString(self, mode):
        return _pycec.ICECAdapter_ToString(self, mode)

    def AudioStatusToString(self, status):
        return _pycec.ICECAdapter_AudioStatusToString(self, status)

    def DeviceTypeToString(self, type):
        return _pycec.ICECAdapter_DeviceTypeToString(self, type)

    def UserControlCodeToString(self, key):
        return _pycec.ICECAdapter_UserControlCodeToString(self, key)

    def AdapterTypeToString(self, type):
        return _pycec.ICECAdapter_AdapterTypeToString(self, type)

    def VersionToString(self, version):
        return _pycec.ICECAdapter_VersionToString(self, version)

    def PrintVersion(self, version, buf, bufSize):
        return _pycec.ICECAdapter_PrintVersion(self, version, buf, bufSize)

    def VendorIdToString(self, vendor):
        return _pycec.ICECAdapter_VendorIdToString(self, vendor)

    def AudioToggleMute(self):
        return _pycec.ICECAdapter_AudioToggleMute(self)

    def AudioMute(self):
        return _pycec.ICECAdapter_AudioMute(self)

    def AudioUnmute(self):
        return _pycec.ICECAdapter_AudioUnmute(self)

    def AudioStatus(self):
        return _pycec.ICECAdapter_AudioStatus(self)

    def CommandFromString(self, strCommand):
        return _pycec.ICECAdapter_CommandFromString(self, strCommand)

    def AudioEnable(self, enable):
        return _pycec.ICECAdapter_AudioEnable(self, enable)

    def SystemAudioModeStatus(self):
        return _pycec.ICECAdapter_SystemAudioModeStatus(self)
    __swig_destroy__ = _pycec.delete_ICECAdapter

    @staticmethod
    def Create(configuration):
        return _pycec.ICECAdapter_Create(configuration)

    def DetectAdapters(self, *args):
        return _pycec.ICECAdapter_DetectAdapters(self, *args)

# Register ICECAdapter in _pycec:
_pycec.ICECAdapter_swigregister(ICECAdapter)

def CECStartBootloader():
    return _pycec.CECStartBootloader()

